@@ -8,9 +8,8 @@ class __Quantifier(_pre.Pregex):
     Constitutes the base class for every class within "quantifiers.py".
     '''
     def __init__(self, pre: _pre.Pregex or str, is_greedy: bool, transform) -> '__Quantifier':
-        if issubclass(pre.__class__, _pre.Pregex):
-            if pre._get_type() in (__class__._PatternType.Assertion, __class__._PatternType.Quantifier):
-                raise _exceptions.CannotBeQuantifiedException(pre)
+        if issubclass(pre.__class__, _pre.Pregex) and pre._get_type() == __class__._PatternType.Assertion:
+            raise _exceptions.CannotBeQuantifiedException(pre)
         pre = transform(__class__._to_pregex(pre), is_greedy)
         super().__init__(str(pre), escape=False)
         self._set_type(__class__._PatternType.Quantifier)
